@@ -29,6 +29,7 @@ COUNTRIES = (
     ('BM', _(u'Bermuda')),
     ('BT', _(u'Bhutan')),
     ('BO', _(u'Bolivia, Plurinational State of')),
+    ('BQ', _(u'Bonaire, Saint Eustatius and Saba')),
     ('BA', _(u'Bosnia and Herzegovina')),
     ('BW', _(u'Botswana')),
     ('BV', _(u'Bouvet Island')),
@@ -58,6 +59,7 @@ COUNTRIES = (
     ('CI', _(u"C\xf4te D'ivoire")),
     ('HR', _(u'Croatia')),
     ('CU', _(u'Cuba')),
+    ('CW', _(u'Cura\xe7ao')),
     ('CY', _(u'Cyprus')),
     ('CZ', _(u'Czech Republic')),
     ('DK', _(u'Denmark')),
@@ -157,7 +159,6 @@ COUNTRIES = (
     ('NR', _(u'Nauru')),
     ('NP', _(u'Nepal')),
     ('NL', _(u'Netherlands')),
-    ('AN', _(u'Netherlands Antilles')),
     ('NC', _(u'New Caledonia')),
     ('NZ', _(u'New Zealand')),
     ('NI', _(u'Nicaragua')),
@@ -189,7 +190,7 @@ COUNTRIES = (
     ('SH', _(u'Saint Helena, Ascension and Tristan Da Cunha')),
     ('KN', _(u'Saint Kitts and Nevis')),
     ('LC', _(u'Saint Lucia')),
-    ('MF', _(u'Saint Martin')),
+    ('MF', _(u'Saint Martin (French Part)')),
     ('PM', _(u'Saint Pierre and Miquelon')),
     ('VC', _(u'Saint Vincent and the Grenadines')),
     ('WS', _(u'Samoa')),
@@ -201,6 +202,7 @@ COUNTRIES = (
     ('SC', _(u'Seychelles')),
     ('SL', _(u'Sierra Leone')),
     ('SG', _(u'Singapore')),
+    ('SX', _(u'Sint Maarten (Dutch Part)')),
     ('SK', _(u'Slovakia')),
     ('SI', _(u'Slovenia')),
     ('SB', _(u'Solomon Islands')),
@@ -282,6 +284,7 @@ COUNTRIES_PLUS = (
     ('BT', _(u'Bhutan')),
     ('VE', _(u'Bolivarian Republic of Venezuela')),
     ('BO', _(u'Bolivia, Plurinational State of')),
+    ('BQ', _(u'Bonaire, Saint Eustatius and Saba')),
     ('BA', _(u'Bosnia and Herzegovina')),
     ('BW', _(u'Botswana')),
     ('BV', _(u'Bouvet Island')),
@@ -312,6 +315,7 @@ COUNTRIES_PLUS = (
     ('CI', _(u"C\xf4te D'ivoire")),
     ('HR', _(u'Croatia')),
     ('CU', _(u'Cuba')),
+    ('CW', _(u'Cura\xe7ao')),
     ('CY', _(u'Cyprus')),
     ('CZ', _(u'Czech Republic')),
     ('KP', _(u"Democratic People's Republic of Korea")),
@@ -414,7 +418,6 @@ COUNTRIES_PLUS = (
     ('NR', _(u'Nauru')),
     ('NP', _(u'Nepal')),
     ('NL', _(u'Netherlands')),
-    ('AN', _(u'Netherlands Antilles')),
     ('NC', _(u'New Caledonia')),
     ('NZ', _(u'New Zealand')),
     ('NI', _(u'Nicaragua')),
@@ -448,10 +451,11 @@ COUNTRIES_PLUS = (
     ('RU', _(u'Russian Federation')),
     ('RW', _(u'Rwanda')),
     ('BL', _(u'Saint Barth\xe9lemy')),
+    ('BQ', _(u'Saint Eustatius and Saba Bonaire')),
     ('SH', _(u'Saint Helena, Ascension and Tristan Da Cunha')),
     ('KN', _(u'Saint Kitts and Nevis')),
     ('LC', _(u'Saint Lucia')),
-    ('MF', _(u'Saint Martin')),
+    ('MF', _(u'Saint Martin (French Part)')),
     ('PM', _(u'Saint Pierre and Miquelon')),
     ('VC', _(u'Saint Vincent and the Grenadines')),
     ('WS', _(u'Samoa')),
@@ -463,6 +467,7 @@ COUNTRIES_PLUS = (
     ('SC', _(u'Seychelles')),
     ('SL', _(u'Sierra Leone')),
     ('SG', _(u'Singapore')),
+    ('SX', _(u'Sint Maarten (Dutch Part)')),
     ('SK', _(u'Slovakia')),
     ('SI', _(u'Slovenia')),
     ('SB', _(u'Solomon Islands')),
@@ -545,6 +550,7 @@ OFFICIAL_COUNTRIES = {
     'BM': u'BERMUDA',
     'BT': u'BHUTAN',
     'BO': u'BOLIVIA, PLURINATIONAL STATE OF',
+    'BQ': u'BONAIRE, SAINT EUSTATIUS AND SABA',
     'BA': u'BOSNIA AND HERZEGOVINA',
     'BW': u'BOTSWANA',
     'BV': u'BOUVET ISLAND',
@@ -574,6 +580,7 @@ OFFICIAL_COUNTRIES = {
     'CI': u"C\xd4TE D'IVOIRE",
     'HR': u'CROATIA',
     'CU': u'CUBA',
+    'CW': u'CURA\xc7AO',
     'CY': u'CYPRUS',
     'CZ': u'CZECH REPUBLIC',
     'DK': u'DENMARK',
@@ -673,7 +680,6 @@ OFFICIAL_COUNTRIES = {
     'NR': u'NAURU',
     'NP': u'NEPAL',
     'NL': u'NETHERLANDS',
-    'AN': u'NETHERLANDS ANTILLES',
     'NC': u'NEW CALEDONIA',
     'NZ': u'NEW ZEALAND',
     'NI': u'NICARAGUA',
@@ -705,7 +711,7 @@ OFFICIAL_COUNTRIES = {
     'SH': u'SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA',
     'KN': u'SAINT KITTS AND NEVIS',
     'LC': u'SAINT LUCIA',
-    'MF': u'SAINT MARTIN',
+    'MF': u'SAINT MARTIN (FRENCH PART)',
     'PM': u'SAINT PIERRE AND MIQUELON',
     'VC': u'SAINT VINCENT AND THE GRENADINES',
     'WS': u'SAMOA',
@@ -717,6 +723,7 @@ OFFICIAL_COUNTRIES = {
     'SC': u'SEYCHELLES',
     'SL': u'SIERRA LEONE',
     'SG': u'SINGAPORE',
+    'SX': u'SINT MAARTEN (DUTCH PART)',
     'SK': u'SLOVAKIA',
     'SI': u'SLOVENIA',
     'SB': u'SOLOMON ISLANDS',
